/*****************************************************************
 File: m_vlinks.c
 Desc: list vlinks and the user count in each one
 Author: openglx@StarByte.net
 Based in m_ircops.c from Hybrid6/PTlink6
*/

#include "m_commands.h"
#include "client.h"
#include "channel.h"
#include "hash.h"
#include "struct.h"
#include "ircd.h"
#include "numeric.h"
#include "s_serv.h"
#include "send.h"
#include "m_silence.h"
#include "list.h"
#include "irc_string.h"
#include "s_conf.h"
#include "dconf_vars.h"
#include "vlinks.h"

#include <string.h>     /* for strchr() */

int m_vlinks(struct Client* cptr, struct Client* sptr, int parc, char* parv[])
{
  struct Client *acptr;
  char buf[BUFSIZE];
  int vlink_count_users = 0;
  int vlink_count_servers = 0;
  int specific_vlink_count = 0;
  struct ConfItem *aconf = vlinks;

  if (!IsAnOper(sptr))
  {
    sendto_one(sptr, form_str(ERR_NOPRIVILEGES), me.name, parv[0]);
    return 0;
  }                       
  
  strcpy(buf, "\212StarByte\2 - Vlink List:");
  sendto_one(sptr, form_str(RPL_LISTS), me.name, parv[0], buf);

  /* first we need the vlink list */
  while(aconf)
    {
       /* this is a valid vlink, so, increase vlink_count_servers */
       vlink_count_servers++;
       
       /* specific_vlink_count is set to 0, because each vlink has it own count of users */
       specific_vlink_count = 0;                      
                                                                   
       for (acptr = GlobalClientList; acptr; acptr = acptr->next)
          {
  	     if (!IsService(acptr) && !IsStealth(acptr) && IsPerson(acptr)) {
    
                 if (!acptr->user->vlink) continue;

                 if (acptr->user->vlink == aconf)
                    specific_vlink_count++;    
             
                  vlink_count_users++;
             
             }     
             
    	  }

       ircsprintf(buf, "%-30s   %d", aconf->name, specific_vlink_count);
       sendto_one(sptr, form_str(RPL_LISTS), me.name, parv[0], buf);
       
       /* don't forget to jump to the next one! */
       aconf=aconf->next;
         
    }
 
  ircsprintf(buf, "Total: \2%d\2 User%s connected in \2%d\2 Vlink%s ", (vlink_count_users / vlink_count_servers), 
        (vlink_count_users) > 1 ? "s" : "", vlink_count_servers, (vlink_count_servers) > 1 ? "s" : "");
  sendto_one(sptr, form_str(RPL_LISTS), me.name, parv[0], buf);
  sendto_one(sptr, form_str(RPL_ENDOFLISTS), me.name, parv[0], "/VLINKS");
  return 0;
}

